========================================================================
C-PAC Python Package |build-status| |github-version| |upload| |coverage|
========================================================================

`cpac-py` was an in-development name for `cpac <https://pypi.org/project/cpac/>`_.

.. |github-version| image:: https://img.shields.io/github/tag/shnizzedy/cpac-python-package.svg
    :target: https://github.com/shnizzedy/cpac-python-package/releases
    :alt: GitHub version
.. |build-status| image:: https://travis-ci.org/shnizzedy/cpac-python-package.svg?branch=trunk
    :target: https://travis-ci.org/shnizzedy/cpac-python-package
    :alt: Travis CI build status
.. |coverage| image:: https://coveralls.io/repos/github/shnizzedy/cpac-python-package/badge.svg?branch=trunk
    :target: https://coveralls.io/github/shnizzedy/cpac-python-package?branch=trunk
    :alt: coverage badge
.. |upload| image:: https://github.com/shnizzedy/cpac-python-package/workflows/Upload%20Python%20Package/badge.svg
    :target: https://pypi.org/project/cpac/
    :alt: upload Python package

